Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 14984)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 14992)
@@ -61,4 +61,6 @@
     IPasswordValidator, IContactForm, IKofaUtils, ICSVExporter,
     academic_sessions_vocab, DOCLINK, registration_states_vocab)
+from waeup.kofa.university.department import Department
+from waeup.kofa.university.course import Course
 from waeup.kofa.permissions import (
     get_users_with_local_roles, get_all_roles, get_all_users,
@@ -1011,6 +1013,12 @@
     @property
     def getCourses(self):
+        courses = []
         local_roles = get_user_account(self.request).getLocalRoles()
-        return local_roles['waeup.local.Lecturer']
+        for item in local_roles.get('waeup.local.Lecturer', []):
+            if isinstance(item, Course):
+                courses.append(item)
+            elif isinstance(item, Department):
+                courses += [i for i in item.courses.values()]
+        return courses
 
 #
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/mycourses.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/mycourses.pt	(revision 14984)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/mycourses.pt	(revision 14992)
@@ -5,6 +5,7 @@
 <div tal:repeat="course view/getCourses">
     <a tal:attributes="href python:view.url(course)">
-      <span tal:content="course/title">ROLE</span>
-      (<span tal:content="course/code">ROLE</span>)
+      <span tal:content="python:course.__parent__.__parent__.__parent__.code">FAC</span> /
+      <span tal:content="python:course.__parent__.__parent__.code">DEP</span> /
+      <span tal:content="course/longtitle">COURSE</span>
     </a>
 </div>
Index: main/waeup.kofa/trunk/src/waeup/kofa/permissions.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/permissions.py	(revision 14984)
+++ main/waeup.kofa/trunk/src/waeup/kofa/permissions.py	(revision 14992)
@@ -205,4 +205,16 @@
 
 
+class DepartmentOfficer(grok.Role):
+    """The local DepartmentOfficer role can be assigned at faculty or
+    department level. The role allows to list all student data within the
+    faculty/department the local role is assigned.
+    """
+    grok.name('waeup.local.DepartmentOfficer')
+    grok.title(u'Department Officer')
+    grok.permissions('waeup.showStudents',
+                     'waeup.viewAcademics',
+                     'waeup.exportPaymentsOverview')
+
+
 class DepartmentManager(grok.Role):
     """The local DepartmentManager role can be assigned at faculty or
@@ -218,20 +230,4 @@
                      'waeup.showStudents',
                      'waeup.exportData')
-
-
-class DepartmentOfficer(grok.Role):
-    """The local DepartmentOfficer role can be assigned at faculty or
-    department level. The role allows to list all student data within the
-    faculty/department the local role is assigned.
-
-    Department Managers (Dean of Faculty or Head of Department respectively)
-    can also list student data but not access student pages. They can
-    furthermore export payment overviews.
-    """
-    grok.name('waeup.local.DepartmentOfficer')
-    grok.title(u'Department Officer')
-    grok.permissions('waeup.showStudents',
-                     'waeup.viewAcademics',
-                     'waeup.exportPaymentsOverview')
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/university/department.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/university/department.py	(revision 14984)
+++ main/waeup.kofa/trunk/src/waeup/kofa/university/department.py	(revision 14992)
@@ -58,4 +58,5 @@
         'waeup.local.CourseAdviser800',
         'waeup.local.LocalStudentsManager',
+        'waeup.local.Lecturer',
         ]
 

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 14984)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 14992)
@@ -3980,5 +3980,5 @@
         self.student['studycourse'].addStudentStudyLevel(
             self.certificate, studylevel)
         # Assign local Lecturer role for a certificate.
         course = self.app['faculties']['fac1']['dep1'].courses['COURSE1']
         prmlocal = IPrincipalRoleManager(course)
@@ -4011,4 +4011,34 @@
         self.assertMatches('...You logged in...', self.browser.contents)
         self.assertEqual(self.browser.url, URL_LECTURER_LANDING)
+        self.assertTrue(
+            "<span>Unnamed Course (COURSE1)</span>"
+            in self.browser.contents)
+
+    def test_lecturer_department_role(self):
+        # lecturers can login and will be led to landing page also if
+        # role is assigned at department level.
+        self.login_as_lecturer()
+        # we remove the role granted above
+        course = self.app['faculties']['fac1']['dep1'].courses['COURSE1']
+        prmlocal = IPrincipalRoleManager(course)
+        prmlocal.removeRoleFromPrincipal('waeup.local.Lecturer', 'mrslecturer')
+        notify(LocalRoleSetEvent(
+            course, 'waeup.local.Lecturer', 'mrslecturer', granted=False))
+        self.browser.open(URL_LECTURER_LANDING)
+        # no course appears
+        self.assertFalse(
+            "<span>Unnamed Course (COURSE1)</span>"
+            in self.browser.contents)
+        # we assign lecturer at department level
+        dep = self.app['faculties']['fac1']['dep1']
+        prmlocal = IPrincipalRoleManager(dep)
+        prmlocal.assignRoleToPrincipal('waeup.local.Lecturer', 'mrslecturer')
+        notify(LocalRoleSetEvent(
+            dep, 'waeup.local.Lecturer', 'mrslecturer', granted=True))
+        self.browser.open(URL_LECTURER_LANDING)
+        # course appears again
+        self.assertTrue(
+            "<span>Unnamed Course (COURSE1)</span>"
+            in self.browser.contents)
 
     def test_my_roles_link_works(self):
@@ -3980,5 +3980,5 @@
         self.student['studycourse'].addStudentStudyLevel(
             self.certificate, studylevel)
-        # Assign local Lecturer role for a certificate.
+        # Assign local Lecturer role for a course.
         course = self.app['faculties']['fac1']['dep1'].courses['COURSE1']
         prmlocal = IPrincipalRoleManager(course)